@import url(https://cdn.jsdelivr.net/npm/bootstrap-icons@1.5.0/font/bootstrap-icons.css);.terminal[data-v-99c560f2]{padding:8px;font-family:courier new}body,html{height:100%;width:100%;margin:0}#app{font-family:Avenir,Helvetica,Arial,sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;height:100%}.form-signin{width:100%;max-width:330px;padding:15px;margin:auto}